from .__version__ import __author__, __email__, __copyright__, __maintainer__
from .__version__ import __credits__, __license__, __description__, __url__
from .__version__ import __version_major__, __version_long__, __version__, __status__
from .sunshine import hello

__all__ = ['hello',
           "__version__", "__author__", "__description__", "__copyright__"]
